rm(list=ls())

library(arm)
library(BRugs)
library(foreign)
library(mcmcplots)

dat<-read.dta("esarey-chirillo.dta")
dat.one<-subset(dat, select=c("wbgi_corr_n", "pwom_tot", "p_polity2", "ccode", "ht_region"))
attach(dat.one)

wbgi.miss<-is.na(wbgi_corr_n)
pwom.miss<-is.na(pwom_tot)
polity.miss<-is.na(p_polity2)

dat$miss.tot<-wbgi.miss+pwom.miss+polity.miss
detach(dat.one)
dat.one<-subset(dat, subset=miss.tot<3, select=c("wbgi_corr_n", "pwom_tot", "p_polity2", "ccode", "ht_region"))
attach(dat.one)




miss<-cbind(pwom_tot, p_polity2)

N<-dim(dat.one)[1]

region<-match(ht_region, unique(ht_region))
J<-length(unique(region))

state<-match(ccode, unique(ccode))
K<-length(unique(ccode))

region.S<-unique(cbind(region, state))[,1]


data<- list("N", "K", "wbgi_corr_n", "miss", "region")
inits <- function() {list (b0 = 0, b1 = 0, b2 = 0, d1 = 0, tau.y = 1, tau.R=1)}
parameters<- c("b0", "b1", "b2", "d1", "tau.y", "tau.R")
regression.sim<-bugs(data, inits, parameters.to.save=parameters, model.file="esarey-chirillo-8.bug", n.chains=1, n.iter=10000, n.burnin=1000, n.thin=1, debug=F, program="WinBUGS", DIC=F)


mcmcplot(regression.sim, dir=getwd(), parms = c("b0", "b1", "b2", "d1", "tau.y", "tau.R"))
denplot(regression.sim, parms=c("d1", "b1"))


polity.plot<-(-10):10
women.effect<-matrix(data=NA, ncol=length(polity.plot), nrow=9000)

for(i in 1:length(polity.plot)){
  women.effect[,i]<-regression.sim$sims.matrix[,"b1"]+regression.sim$sims.matrix[,"d1"]*polity.plot[i]
}


ci.plot<-apply(X=women.effect, FUN=quantile, MARGIN=2, probs=c(0.025, 0.5, 0.975))
plot(ci.plot[2,]~polity.plot, type="l", ylim=c(-5,5))
lines(ci.plot[1,]~polity.plot, lty=2)
lines(ci.plot[3,]~polity.plot, lty=2)
abline(h=0)


detach(dat.one)

