
library(arm)
library(BRugs)
library(foreign)
library(mcmcplots)

dat<-read.dta("esarey-chirillo.dta")
dat.one<-subset(dat, select=c("wbgi_corr_n", "pwom_tot_i", "p_polity2", "ht_region"))
dat.one<-na.omit(dat.one)
attach(dat.one)

N<-dim(dat.one)[1]



region<-match(ht_region, unique(ht_region))
K<-length(unique(region))

data<- list("N", "K", "wbgi_corr_n", "pwom_tot_i", "p_polity2", "region")
inits <- function() {list (b0 = 0, b1 = 0, b2 = 0, d1 = 0, tau.y = 1, tau.R=1)}
parameters<- c("b0", "b1", "b2", "d1", "tau.y", "tau.R")
regression.sim<-bugs(data, inits, parameters.to.save=parameters, model.file="esarey-chirillo-9.bug", n.chains=1, n.iter=10000, n.burnin=1000, n.thin=1, debug=F, program="WinBUGS", DIC=F)


mcmcplot(regression.sim, dir=getwd(), parms = c("b0", "b1", "b2", "d1", "tau.y", "tau.R"))
denplot(regression.sim, parms=c("d1", "b2"))


polity.plot<-(-10):10
women.effect<-matrix(data=NA, ncol=length(polity.plot), nrow=9000)

for(i in 1:length(polity.plot)){
  women.effect[,i]<-regression.sim$sims.matrix[,"b1"]+regression.sim$sims.matrix[,"d1"]*polity.plot[i]
}


ci.plot<-apply(X=women.effect, FUN=quantile, MARGIN=2, probs=c(0.025, 0.5, 0.975))
plot(ci.plot[2,]~polity.plot, type="l", ylim=c(-2.2,4.2))
lines(ci.plot[1,]~polity.plot, lty=2)
lines(ci.plot[3,]~polity.plot, lty=2)
abline(h=0)


detach(dat.one)

