rm(list=ls())
library(arm)
library(BRugs)
library(foreign)
library(rjags)

set.seed(1238120)


state<-c()
county<-c()
republican<-c()
own.status<-c()
incumbent<-c()

for(i in 1:4){
  
  republican.S<-runif(1, min=0.4, max=0.6)
  culture.S<-rnorm(1, mean=0, sd=0.5)
  
  if(i==1){C.start<-1}else{C.start<-1+county[length(county)]}
  
  for(j in C.start:(C.start+round(runif(1, min=10, max=60)))){
    
    republican.C<-runif(1, min=-0.4, max=0.4)
    culture.C<-rnorm(1, mean=culture.S, sd=0.25)
    
    N=runif(1, min=5, max=100)
    
    state<-c(state, rep(i, N))
    county<-c(county, rep(j, N))
    
    republican.T<-rbinom(N, size=1, prob=(republican.S+republican.C))
    own.status.T<-runif(N, min=0, max=100)
    
    xb<- -2 + culture.C + 1.2*republican.T + 0.05*own.status.T
    pr.inc<-pnorm(xb)
    
    incumbent.T<-rbinom(N, size=1, prob=pr.inc)
    
    
    republican<-c(republican, republican.T)
    own.status<-c(own.status, own.status.T)
    incumbent<-c(incumbent, incumbent.T)
    
  }
  
  
}

dat.example<-data.frame(incumbent, republican, own.status, state, county)

simple.model<-glm(incumbent~republican+own.status, family=binomial(link="probit"), data=dat.example)
summary(simple.model)




N<-dim(dat.example)[1]
K<-length(unique(state))
J<-length(unique(county))
state.C<-unique(cbind(state, county))[,1]


data<- list("N" = N, "K"=K, "J" = J, "incumbent" = incumbent, "republican" = republican, "own.status" = own.status, "county"= county, "state.C"= state.C)
inits <- function() {list (b0 = 0, b1 = 0, b2 = 0, incumbent.pred = incumbent)}
parameters<- c("b0", "b1", "b2", "ranef", "ranef.S", "incumbent.pred")
#probit.sim<-bugs(data, inits, parameters.to.save=parameters, model.file="vote-example-2.bug", n.chains=1, n.iter=5000, n.burnin=1000, n.thin=1, debug=F, program="openbugs")
probit.sim<-jags.model(file="vote-example-2.bug", data, inits, n.chains=1, n.adapt=1000)
update(probit.sim, n.iter=1000) # burn in
probit.samples<-coda.samples(probit.sim, variable.names=parameters, n.iter=5000)

#summary(probit.samples)
library(mcmcplots)
mcmcplot(probit.samples, dir=getwd(), parms=c("b0", "b1", "b2"))

denplot(probit.samples, parms=c("b0", "b1", "b2"))
caterplot(probit.samples, parms=c("ranef.S", "ranef"))
caterplot(probit.samples, parms="ranef.S")

probit.samples.mcmc<-as.mcmc(probit.samples)
VOTES<-probit.samples.mcmc[,4:7703]

vote.sums<-apply(X=VOTES, FUN=sum, MARGIN=1)
vote.pct<-vote.sums/length(incumbent)
hist(vote.pct)

# distribution of votes in state 1?
state.ind<-state==1
state.ind<-which(state.ind==T)
VOTES.ST1<-VOTES[,state.ind]

vote.sums<-apply(X=VOTES.ST1, FUN=sum, MARGIN=1)
vote.pct.st1<-vote.sums/length(state.ind)
hist(vote.pct.st1)


# distribution of votes in all counties in State 1?

county.lim<-which(state.C==1)
vote.pct<-matrix(data=NA, ncol=length(county.lim), nrow=5000)
samplesize<-c()

for(i in county.lim){
  county.ind<-county==i
  county.ind<-which(county.ind==T)
  VOTES.CS<-VOTES[,county.ind]
  vote.sums<-apply(X=VOTES.CS, FUN=sum, MARGIN=1)
  vote.pct[,i]<-vote.sums/length(county.ind)
  samplesize[i]<-length(county.ind)
}

boxplot(cbind(vote.pct.st1, vote.pct))

samplesize
county.ind<-which(county==6)
mean(dat.example$incumbent[county.ind])
mean(vote.pct[,6])



probit.samples.mat<-as.matrix(probit.samples)

plot(density(probit.samples.mat[,"ranef.S[1]"]), xlim=c(-4, -1))
lines(density(probit.samples.mat[,"ranef[6]"]), lty=2)
lines(density(probit.samples.mat[,"ranef[7]"]), lty=3)
